@@ -18,7 +18,7 @@ use Readonly;
 use Data::Walk;
 use Try::Tiny;
 
-our $VERSION = 0.11;
+our $VERSION = 1.02;
 
 our $override;
 my $JSON_OBJ = Cpanel::JSON::XS->new()->utf8->pretty();
@@ -219,7 +219,8 @@ sub _override_dbi_execute {
               if ref $self->{bind_params}
               && scalar @{ $self->{bind_params} } > 0;
 
-            push @{ $self->{result} }, $query_data;
+            push @{ $self->{result} }, $query_data
+              if $sql !~ m/BEGIN|COMMIT/;
             $self->_write_to_file();
             $self->{bind_params} = [];
             $self->{sth}         = $sth;
@@ -881,8 +882,6 @@ DBD::Mock::Session::GenerateFixtures - A module to generate fixtures for DBD::Mo
 	try {
 		$login_history->save();
 		$login_history->db()->dbh()->commit();
-		is( $login_history->db()->dbh()->err(),
-			 undef, 'begin_work and commit are found in session' );
 	}
 	catch {
 	 $login_history->db()->dbh()->rollback();
